"""
Double toggle on-off DTR with ping
Fails each second time
"""

import serial
import time


def ping(ser, name, value, expected_data=None, expected_len=0):
    while True:
        print("Sending", name)
        ser.write(value)
        ser.flush()
        time.sleep(0.01)
        print("Reading", name, "response")
        response = ser.read(len(expected_data) if expected_data is not None else (expected_len + 3) * 2)
        if expected_data is not None and expected_data == response:
            print("Pings are matched")
            return
        elif expected_len and len(response) == (expected_len + 3) * 2:
            print("Pings are matched")
            return
        else:
            print(response, "not matches", name)


with serial.Serial('/dev/ttyUSB0',
                   baudrate=115200,
                   timeout=1.0,
                   parity=serial.PARITY_NONE,
                   rtscts=False,
                   dsrdtr=False,
                   xonxoff=False,
                   bytesize=serial.EIGHTBITS,
                   stopbits=serial.STOPBITS_ONE) as ser:
    print("Port: ", ser.name)
    ser.rts = True
    ser.dtr = True
    ser.flush()
    ser.reset_input_buffer()
    ser.reset_output_buffer()
    time.sleep(0.01)
    ser.dtr = False
    time.sleep(0.2)
    ser.dtr = True
    time.sleep(0.2)
    ser.dtr = False
    time.sleep(0.1)
    ser.reset_input_buffer()
    ser.reset_output_buffer()

    ping(ser, "ping", b'{100000139306}', expected_len=19)
    ping(ser, "header", b'{123DBA}', expected_data=b'{!D5B3}')

    nbytes = 0
    data = b''

    while nbytes < 32000:
        rlen = min(max(1024, ser.in_waiting), 32000 - nbytes)
        print("Reading packet %d bytes" % (rlen,))
        packet = ser.read(rlen)
        time.sleep(0.01)
        got = len(packet)
        print("Got %4d bytes: " % (got,), packet)
        data += packet
        nbytes += got

    print("Reading trailer 4 bytes")
    trailer = ser.read(4)
    print("Trailer is: ", trailer)
